@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "cycle-at-point" "20250913.2251"
-  "Cycle (rotate) the thing under the cursor."
+(define-package "cycle-at-point" "20260111.1240"
+  "Cycle (rotate) the word at point."
   '((emacs      "29.1")
     (recomplete "0.2"))
   :url "https://codeberg.org/ideasman42/emacs-cycle-at-point"
-  :commit "c390803221816319ae6edcea470d12a4849606af"
-  :revdesc "c39080322181"
+  :commit "0af1fa35f49d320960870b9dbcb4d03440139fdf"
+  :revdesc "0af1fa35f49d"
   :keywords '("convenience")
   :authors '(("Campbell Barton" . "ideasman42@gmail.com"))
   :maintainers '(("Campbell Barton" . "ideasman42@gmail.com")))
